pilas.motores.motor_qt.Lienzo

Package pilas :: Package motores :: Module motor_qt :: Class Lienzo |
[hide private]
[frames] | no frames]

# Class Lienzo

source code

    object --+
             |
        Imagen --+
                 |
                Lienzo

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
texto(self, painter, cadena, x=0, y=0, magnitud=10, fuente=None, color=colores.negro) Imprime un texto respespetando el desplazamiento de la camara. | source code
texto_absoluto(self, painter, cadena, x=0, y=0, magnitud=10, fuente=None, color=colores.negro) Imprime un texto sin respetar al camara. | source code
pintar(self, painter, color) | source code
linea(self, painter, x0, y0, x1, y1, color=colores.negro, grosor=1) | source code
poligono(self, motor, puntos, color=colores.negro, grosor=1, cerrado=False) | source code
cruz(self, painter, x, y, color=colores.negro, grosor=1) | source code
circulo(self, painter, x, y, radio, color=colores.negro, grosor=1) | source code
rectangulo(self, painter, x, y, ancho, alto, color=colores.negro, grosor=1) | source code
Inherited from `Imagen`: `__str__`, `alto`, `ancho`, `avanzar`, `cargar_jpeg`, `centro`, `dibujar` Inherited from `Imagen` (private): `_dibujar_pixmap` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)